#source: ../../../lns/lns-common-1.s
#readelf: -wl
#name: lns-common-1
Raw dump of debug contents of section \.z?debug_line:
#...
  Initial value of 'is_stmt':  1
#...
 Line Number Statements:
  \[0x.*\]  Extended opcode 2: set Address to .*
  \[0x.*\]  Copy
  \[0x.*\]  Set column to 3
  \[0x.*\]  Special opcode .*: advance Address by .* to .* and Line by 1 to 2
  \[0x.*\]  Set prologue_end to true
  \[0x.*\]  Special opcode .*: advance Address by .* to .* and Line by 1 to 3
  \[0x.*\]  Set column to 0
  \[0x.*\]  Set epilogue_begin to true
  \[0x.*\]  Special opcode .*: advance Address by .* to .* and Line by 1 to 4
  \[0x.*\]  Set ISA to 1
  \[0x.*\]  Set basic block
  \[0x.*\]  Special opcode .*: advance Address by .* to .* and Line by 1 to 5
  \[0x.*\]  Set is_stmt to 0
  \[0x.*\]  Special opcode .*: advance Address by .* to .* and Line by 1 to 6
  \[0x.*\]  Set is_stmt to 1
  \[0x.*\]  Special opcode .*: advance Address by .* to .* and Line by 1 to 7
  \[0x.*\]  Extended opcode 4: set Discriminator to 1
  \[0x.*\]  Special opcode .*: advance Address by .* to .* and Line by 0 to 7
  \[0x.*\]  Advance PC by .* to .*
  \[0x.*\]  Extended opcode 1: End of Sequence
#...
