	.file 1 "foo.c"
	.loc 1 1
	nop
	nop
	.loc 1 2 3
	nop
	nop
	.loc 1 3 prologue_end
	nop
	nop
	.loc 1 4 0 epilogue_begin
	nop
	nop
	.loc 1 5 isa 1 basic_block
	nop
	nop
	.loc 1 6 is_stmt 0
	nop
	nop
	.loc 1 7 is_stmt 1
	nop
	nop
	.loc 1 7 discriminator 1
	nop
	nop
