[^:]*: Assembler messages:
[^:]*:18: Error: ARM register expected -- `add foo,foo,foo'
[^:]*:21: Warning: ignoring attempt to use .unreq on fixed register name: 'r0'
[^:]*:41: Warning: ignoring redefinition of register alias 'FOO'
