#readelf: -wl
#source: prefix.s
#as: --em=criself --gdwarf2

# Various prefixes, assembled standalone.
#...
 Line Number Statements:
  \[0x.*\]  Extended opcode 2: set Address to 0x0
  \[0x.*\]  Special opcode .*: advance Address by 0 to 0x0 and Line by 8 to 9
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x2 and Line by 1 to 10
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x4 and Line by 2 to 12
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x6 and Line by 1 to 13
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8 and Line by 2 to 15
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xa and Line by 1 to 16
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xc and Line by 2 to 18
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xe and Line by 1 to 19
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x10 and Line by 2 to 21
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x12 and Line by 1 to 22
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x14 and Line by 2 to 24
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x16 and Line by 1 to 25
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x18 and Line by 2 to 27
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1a and Line by 1 to 28
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1c and Line by 2 to 30
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1e and Line by 1 to 31
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x20 and Line by 6 to 37
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x24 and Line by 1 to 38
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x26 and Line by 2 to 40
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x2a and Line by 1 to 41
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x2c and Line by 2 to 43
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x30 and Line by 1 to 44
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x32 and Line by 2 to 46
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x36 and Line by 1 to 47
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x38 and Line by 2 to 49
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x3c and Line by 1 to 50
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x3e and Line by 2 to 52
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x42 and Line by 1 to 53
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x44 and Line by 2 to 55
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x48 and Line by 1 to 56
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x4a and Line by 2 to 58
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x4e and Line by 1 to 59
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x50 and Line by 2 to 61
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x54 and Line by 1 to 62
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x56 and Line by 2 to 64
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x5a and Line by 1 to 65
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x5c and Line by 2 to 67
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x60 and Line by 1 to 68
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x62 and Line by 2 to 70
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x66 and Line by 1 to 71
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x68 and Line by 2 to 73
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x6c and Line by 1 to 74
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x6e and Line by 2 to 76
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x72 and Line by 1 to 77
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x74 and Line by 2 to 79
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x7a and Line by 1 to 80
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x7c and Line by 2 to 82
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x82 and Line by 1 to 83
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x84 and Line by 2 to 85
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x8a and Line by 1 to 86
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8c and Line by 2 to 88
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x92 and Line by 1 to 89
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x94 and Line by 2 to 91
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x9a and Line by 1 to 92
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x9c and Line by 2 to 94
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0xa2 and Line by 1 to 95
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xa4 and Line by 2 to 97
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0xaa and Line by 1 to 98
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xac and Line by 2 to 100
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0xb2 and Line by 1 to 101
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xb4 and Line by 2 to 103
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0xba and Line by 1 to 104
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xbc and Line by 2 to 106
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0xc2 and Line by 1 to 107
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xc4 and Line by 2 to 109
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0xca and Line by 1 to 110
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xcc and Line by 2 to 112
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0xd2 and Line by 1 to 113
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xd4 and Line by 2 to 115
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0xda and Line by 1 to 116
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xdc and Line by 2 to 118
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0xe2 and Line by 1 to 119
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xe4 and Line by 2 to 121
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0xea and Line by 1 to 122
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xec and Line by 2 to 124
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0xf2 and Line by 1 to 125
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xf4 and Line by 2 to 127
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xf6 and Line by 1 to 128
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xf8 and Line by 2 to 130
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xfa and Line by 1 to 131
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xfc and Line by 2 to 133
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0xfe and Line by 1 to 134
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x100 and Line by 2 to 136
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x102 and Line by 1 to 137
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x104 and Line by 2 to 139
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x106 and Line by 1 to 140
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x108 and Line by 2 to 142
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x10a and Line by 1 to 143
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x10c and Line by 2 to 145
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x10e and Line by 1 to 146
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x110 and Line by 2 to 148
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x112 and Line by 1 to 149
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x114 and Line by 2 to 151
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x116 and Line by 1 to 152
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x118 and Line by 6 to 158
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x11a and Line by 1 to 159
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x11c and Line by 2 to 161
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x11e and Line by 1 to 162
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x120 and Line by 2 to 164
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x122 and Line by 1 to 165
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x124 and Line by 2 to 167
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x126 and Line by 1 to 168
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x128 and Line by 2 to 170
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x12a and Line by 1 to 171
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x12c and Line by 2 to 173
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x12e and Line by 1 to 174
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x130 and Line by 2 to 176
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x132 and Line by 1 to 177
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x134 and Line by 2 to 179
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x136 and Line by 1 to 180
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x138 and Line by 2 to 182
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x13a and Line by 1 to 183
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x13c and Line by 5 to 188
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x142 and Line by 1 to 189
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x144 and Line by 2 to 191
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x14a and Line by 1 to 192
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x14c and Line by 2 to 194
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x152 and Line by 1 to 195
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x154 and Line by 2 to 197
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x15a and Line by 1 to 198
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x15c and Line by 2 to 200
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x162 and Line by 1 to 201
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x164 and Line by 2 to 203
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x16a and Line by 1 to 204
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x16c and Line by 2 to 206
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x172 and Line by 1 to 207
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x174 and Line by 2 to 209
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x17a and Line by 1 to 210
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x17c and Line by 2 to 212
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x182 and Line by 1 to 213
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x184 and Line by 2 to 215
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x18a and Line by 1 to 216
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x18c and Line by 2 to 218
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x192 and Line by 1 to 219
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x194 and Line by 2 to 221
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x19a and Line by 1 to 222
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x19c and Line by 2 to 224
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x1a2 and Line by 1 to 225
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1a4 and Line by 2 to 227
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x1aa and Line by 1 to 228
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1ac and Line by 2 to 230
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x1b2 and Line by 1 to 231
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1b4 and Line by 2 to 233
  \[0x.*\]  Special opcode .*: advance Address by 6 to 0x1ba and Line by 1 to 234
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1bc and Line by 2 to 236
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1be and Line by 1 to 237
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1c0 and Line by 2 to 239
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1c2 and Line by 1 to 240
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1c4 and Line by 2 to 242
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1c6 and Line by 1 to 243
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1c8 and Line by 2 to 245
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x1ca and Line by 1 to 246
  \[0x.*\]  Advance PC by 2 to 0x1cc
  \[0x.*\]  Extended opcode 1: End of Sequence
