# j test

text_label:

	j	text_label
	jal	text_label
	jra	text_label
	jeq	text_label
	jz	text_label
	jne	text_label
	jnz	text_label
	jpl	text_label
	jp	text_label
	jmi	text_label
	jn	text_label
	jcs	text_label
	jc	text_label
	jlo	text_label
	jcc	text_label
	jnc	text_label
	jhs	text_label
	jvs	text_label
	jv	text_label
	jvc	text_label
	jnv	text_label
	jgt	text_label
	jge	text_label
	jlt	text_label
	jle	text_label
	jhi	text_label
	jls	text_label
	jpnz	text_label

	j	external_text_label

	j	0
