#objdump: -dr

dump\.o:     file format .*


Disassembly of section \.text:

00000000 <\.text>:
   0:	7f a9                         	setpsw	u
   2:	7f a8                         	setpsw	i
   4:	7f a3                         	setpsw	o
   6:	7f a2                         	setpsw	s
   8:	7f a1                         	setpsw	z
   a:	7f a0                         	setpsw	c
