
.*:     file format .*

DYNAMIC RELOCATION RECORDS
OFFSET +TYPE +VALUE 
[^ ]+ R_ARM_REL32 +foo
[^ ]+ R_ARM_REL32 +foo
[^ ]+ R_ARM_JUMP_SLOT +foo


Contents of section \.data:
 [^ ]+ 00000000 (00010000|00000100)  .*
