	.text
	.arch i386
i386:
	movsbl %al,%esi
	.p2align 4

	.arch i486
i486:
	movsbl %al,%esi
	.p2align 4

	.arch i586
i586:
	movsbl %al,%esi
	.p2align 4

	.arch i686
i686:
	movsbl %al,%esi
	.p2align 4

	.arch pentium4
pentium4:
	movsbl %al,%esi
	.p2align 4

	.arch nocona
nocona:
	movsbl %al,%esi
	.p2align 4

	.arch core
core:
	movsbl %al,%esi
	.p2align 4

	.arch core2
core2:
	movsbl %al,%esi
	.p2align 4

	.arch k6
k6:
	movsbl %al,%esi
	.p2align 4

	.arch athlon
athlon:
	movsbl %al,%esi
	.p2align 4

	.arch k8
k8:
	movsbl %al,%esi
	.p2align 4

	.arch generic32
generic32:
	movsbl %al,%esi
	.p2align 4

	.arch generic64
generic64:
	movsbl %al,%esi
	.p2align 4

	.arch amdfam10
amdfam10:
	movsbl %al,%esi
	.p2align 4
