
Primary GOT:
 Canonical gp value: 12348080

 Reserved entries:
   Address     Access  Initial Purpose
  12340090 -32752\(gp\) 00000000 Lazy resolver
  12340094 -32748\(gp\) 80000000 Module pointer \(GNU extension\)

 Local entries:
   Address     Access  Initial
  12340098 -32744\(gp\) 12340060
  1234009c -32740\(gp\) 12340070
  123400a0 -32736\(gp\) 12340080
