
.*thumb2-bl:     file format elf32-.*arm.*

Disassembly of section .text:

00001000 <_start>:
    1000:	f3ff d7fe 	bl	1001000 <bar>
Disassembly of section .foo:

01001000 <bar>:
 1001000:	4770      	bx	lr
