.*: Assembler messages:
.*:5: Error: too many lituse insns for !lituse_tlsgd!1
.*:10: Error: too many lituse insns for !lituse_tlsldm!2
.*:15: Error: too many lituse insns for !lituse_tlsgd!3
.*:20: Error: too many lituse insns for !lituse_tlsldm!4
.*:23: Error: duplicate !tlsgd!5
.*:26: Error: duplicate !tlsldm!6
.*:29: Error: sequence number in use for !tlsgd!7
.*:32: Error: sequence number in use for !tlsldm!8
