#objdump: -P section
.*: +file format mach-o.*
#...
 Section: __text           __TEXT           \(bfdname: .text\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 80000000 \(type: regular attr: pure_instructions\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __data           __DATA           \(bfdname: .data\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __textcoal_nt    __TEXT           \(bfdname: __TEXT.__textcoal_nt\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 8000000b \(type: coalesced attr: pure_instructions\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __text_hot       __TEXT           \(bfdname: __TEXT.__text_hot\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 80000000 \(type: regular attr: pure_instructions\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __text_cold      __TEXT           \(bfdname: __TEXT.__text_cold\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 80000000 \(type: regular attr: pure_instructions\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __text_startup   __TEXT           \(bfdname: __TEXT.__text_startup\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 80000000 \(type: regular attr: pure_instructions\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __text_exit      __TEXT           \(bfdname: __TEXT.__text_exit\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 80000000 \(type: regular attr: pure_instructions\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __text_hot_coal  __TEXT           \(bfdname: __TEXT.__text_hot_coal\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 8000000b \(type: coalesced attr: pure_instructions\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __text_cold_coal __TEXT           \(bfdname: __TEXT.__text_cold_coal\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 8000000b \(type: coalesced attr: pure_instructions\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __text_stt_coal  __TEXT           \(bfdname: __TEXT.__text_stt_coal\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 8000000b \(type: coalesced attr: pure_instructions\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __text_exit_coal __TEXT           \(bfdname: __TEXT.__text_exit_coal\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 8000000b \(type: coalesced attr: pure_instructions\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __const          __TEXT           \(bfdname: .const\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __const_coal     __TEXT           \(bfdname: __TEXT.__const_coal\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 0000000b \(type: coalesced attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __zobj_const     __DATA           \(bfdname: __DATA.__zobj_const\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __static_data    __DATA           \(bfdname: .static_data\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __datacoal_nt    __DATA           \(bfdname: __DATA.__datacoal_nt\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 0000000b \(type: coalesced attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __zobj_data      __DATA           \(bfdname: __DATA.__zobj_data\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __zobj_bss       __DATA           \(bfdname: __DATA.__zobj_bss\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __const          __DATA           \(bfdname: .const_data\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __const_coal     __DATA           \(bfdname: __DATA.__const_coal\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 0000000b \(type: coalesced attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __zobj_cnst_data __DATA           \(bfdname: __DATA.__zobj_cnst_data\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __cstring        __TEXT           \(bfdname: .cstring\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: (0|2)  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000002 \(type: cstring_literals attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __literal4       __TEXT           \(bfdname: .literal4\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 2  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000003 \(type: 4byte_literals attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __literal8       __TEXT           \(bfdname: .literal8\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 3  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000004 \(type: 8byte_literals attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __literal16      __TEXT           \(bfdname: .literal16\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 4  nreloc: 0  reloff: (00000000)?00000000
  flags: 0000000e \(type: 16byte_literals attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __cfstring       __DATA           \(bfdname: .cfstring\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 2  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __mod_init_func  __DATA           \(bfdname: .mod_init_func\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 2  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000009 \(type: mod_init_func_pointers attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __mod_term_func  __DATA           \(bfdname: .mod_term_func\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 2  nreloc: 0  reloff: (00000000)?00000000
  flags: 0000000a \(type: mod_fini_func_pointers attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __constructor    __TEXT           \(bfdname: .constructor\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __destructor     __TEXT           \(bfdname: .destructor\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __dyld           __DATA           \(bfdname: .dyld\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 00000000 \(type: regular attr: -\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __class          __OBJC           \(bfdname: .objc_class\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __meta_class     __OBJC           \(bfdname: .objc_meta_class\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __cat_cls_meth   __OBJC           \(bfdname: .objc_cat_cls_meth\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __cat_inst_meth  __OBJC           \(bfdname: .objc_cat_inst_meth\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __protocol       __OBJC           \(bfdname: .objc_protocol\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __string_object  __OBJC           \(bfdname: .objc_string_object\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __cls_meth       __OBJC           \(bfdname: .objc_cls_meth\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __inst_meth      __OBJC           \(bfdname: .objc_inst_meth\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __cls_refs       __OBJC           \(bfdname: .objc_cls_refs\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000005 \(type: literal_pointers attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __message_refs   __OBJC           \(bfdname: .objc_message_refs\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000005 \(type: literal_pointers attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __symbols        __OBJC           \(bfdname: .objc_symbols\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __category       __OBJC           \(bfdname: .objc_category\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __class_vars     __OBJC           \(bfdname: .objc_class_vars\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __instance_vars  __OBJC           \(bfdname: .objc_instance_vars\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __module_info    __OBJC           \(bfdname: .objc_module_info\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __selector_strs  __OBJC           \(bfdname: .objc_selector_strs\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000002 \(type: cstring_literals attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __sel_fixup      __OBJC           \(bfdname: .objc_selector_fixup\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __image_info     __OBJC           \(bfdname: .objc_image_info\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __class_ext      __OBJC           \(bfdname: .objc1_class_ext\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __property       __OBJC           \(bfdname: .objc1_property_list\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __protocol_ext   __OBJC           \(bfdname: .objc1_protocol_ext\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __objc_classrefs __DATA           \(bfdname: __DATA.__objc_classrefs\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __objc_classlist __DATA           \(bfdname: __DATA.__objc_classlist\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __objc_catlist   __DATA           \(bfdname: __DATA.__objc_catlist\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __objc_selrefs   __DATA           \(bfdname: __DATA.__objc_selrefs\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000005 \(type: literal_pointers attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __objc_nlclslist __DATA           \(bfdname: __DATA.__objc_nlclslist\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __objc_nlcatlist __DATA           \(bfdname: __DATA.__objc_nlcatlist\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __objc_protolist __DATA           \(bfdname: __DATA.__objc_protolist\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __objc_protorefs __DATA           \(bfdname: __DATA.__objc_protorefs\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __objc_superrefs __DATA           \(bfdname: __DATA.__objc_superrefs\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __objc_imageinfo __DATA           \(bfdname: __DATA.__objc_imageinfo\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __objc_stringobj __DATA           \(bfdname: __DATA.__objc_stringobj\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 10000000 \(type: regular attr: no_dead_strip\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_frame    __DWARF          \(bfdname: .debug_frame\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_info     __DWARF          \(bfdname: .debug_info\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_abbrev   __DWARF          \(bfdname: .debug_abbrev\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_aranges  __DWARF          \(bfdname: .debug_aranges\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_macinfo  __DWARF          \(bfdname: .debug_macinfo\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_line     __DWARF          \(bfdname: .debug_line\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_loc      __DWARF          \(bfdname: .debug_loc\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_pubnames __DWARF          \(bfdname: .debug_pubnames\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_pubtypes __DWARF          \(bfdname: .debug_pubtypes\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_str      __DWARF          \(bfdname: .debug_str\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_ranges   __DWARF          \(bfdname: .debug_ranges\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
 Section: __debug_macro    __DWARF          \(bfdname: .debug_macro\)
  addr: (00000000)?00000000 size: (00000000)?00000000 offset: (00000000)?00000000
  align: 0  nreloc: 0  reloff: (00000000)?00000000
  flags: 02000000 \(type: regular attr: debug\)
  reserved1: 0x0  reserved2: 0x0  reserved3: 0x0
#pass
