/* Copyright (C) 2007-2015 Free Software Foundation, Inc.

   This file is part of BFD, the Binary File Descriptor library.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
   MA 02110-1301, USA.  */

/* Linux dumps "struct task_struct" at the end of the core-file.  This
   structure is currently 2512 bytes long, but we allow up to 4096
   bytes to allow for some future growth.  */
#define TRAD_CORE_EXTRA_SIZE_ALLOWED		4096
#define TRAD_UNIX_CORE_FILE_FAILING_SIGNAL(abfd) \
  ((abfd)->tdata.trad_core_data->u.signal)
