	.section ".tbss"
	.align	4
	.globl sH1, sH2, sH3, sH4, sH5, sH6, sH7, sH8
	.hidden sH1, sH2, sH3, sH4, sH5, sH6, sH7, sH8
sH1:	.word 0
sH2:	.word 0
sH3:	.word 0
sH4:	.word 0
sH5:	.word 0
sH6:	.word 0
sH7:	.word 0
sH8:	.word 0
