.*: Assembler messages:
.*:2: Error: invalid operands `save \$3,100'
.*:3: Error: missing frame size `save \$4'
.*:4: Error: frame size specified twice `save \$4,100,200'
.*:5: Error: operand 2 must be constant `save \$4,foo'
.*:7: Error: invalid frame size `save \$4,1'
.*:8: Error: invalid frame size `save \$4,7'
.*:10: Error: invalid frame size `save \$4,12'
.*:11: Error: invalid frame size `save \$4,2048'
.*:12: Error: invalid frame size `save \$4,2052'
.*:14: Error: invalid operands `save \$4,\$6,0'
.*:15: Error: invalid operands `save 0,\$5,\$7'
.*:18: Error: invalid operands `save \$16,\$18,\$20,0'
