[^:]*: Assembler messages:
[^:]*:4: Error: instruction does not support writeback -- `fstd d0,\[r0\],#8'
[^:]*:5: Error: instruction does not support writeback -- `fstd d0,\[r0,#-8\]!'
[^:]*:6: Error: instruction does not support writeback -- `fsts s0,\[r0\],#8'
[^:]*:7: Error: instruction does not support writeback -- `fsts s0,\[r0,#-8\]!'
[^:]*:8: Error: instruction does not support writeback -- `fldd d0,\[r0\],#8'
[^:]*:9: Error: instruction does not support writeback -- `fldd d0,\[r0,#-8\]!'
[^:]*:10: Error: instruction does not support writeback -- `flds s0,\[r0\],#8'
[^:]*:11: Error: instruction does not support writeback -- `flds s0,\[r0,#-8\]!'
