#source: ../../../lns/lns-duplicate.s
#readelf: -wl
#name: lns-duplicate
Raw dump of debug contents of section \.z?debug_line:
#...
 Line Number Statements:
  \[0x.*\]  Extended opcode 2: set Address to .*
  \[0x.*\]  Copy
  \[0x.*\]  Set basic block
  \[0x.*\]  .* by 1 to 2
#pass
