^[^:]*: Assembler messages:
^[^:]*:16: IT blocks containing 16-bit Thumb instructions of the following class are deprecated in ARMv8: Short branches, Undefined, SVC, LDM/STM
^[^:]*:21: IT blocks containing 32-bit Thumb instructions are deprecated in ARMv8
