#source: b-twoinsn.s
#source: b-bstab1.s
#source: b-post1.s
#source: b-goodmain.s
#ld: --oformat binary
#objcopy_linked_file:
#error: invalid mmo file: fields y and z of lop_stab non-zero, y: 1, z: 2
