.*: Assembler messages:
.*:39: Error: opcode not supported in the `insn32' mode `nop16'
.*:98: Error: opcode not supported in the `insn32' mode `move16 \$2,\$22'
.*:99: Error: opcode not supported in the `insn32' mode `move16 \$22,\$2'
.*:106: Error: opcode not supported in the `insn32' mode `b16 test'
.*:111: Error: opcode not supported in the `insn32' mode `b16 1f'
.*:117: Error: opcode not supported in the `insn32' mode `b16 1b'
.*:277: Error: opcode not supported in the `insn32' mode `and16 \$2,\$2,\$3'
.*:315: Error: opcode not supported in the `insn32' mode `andi16 \$7,65535'
.*:387: Error: opcode not supported in the `insn32' mode `beqz16 \$16,test2'
.*:475: Error: opcode not supported in the `insn32' mode `bnez16 \$16,test3'
.*:578: Warning: divide by zero
.*:581: Warning: divide by zero
.*:594: Warning: divide by zero
.*:1559: Warning: divide by zero
.*:1562: Warning: divide by zero
.*:1575: Warning: divide by zero
.*:2622: Warning: branch bge is always true
.*:2625: Warning: branch bgeu is always true
.*:2634: Warning: branch bgeu is always true
.*:2709: Warning: branch ble is always true
.*:2724: Warning: branch bleu is always true
.*:2730: Warning: branch bleu is always true
.*:2733: Warning: branch bleu is always true
.*:2832: Warning: branch bgel is always true
.*:2835: Warning: branch bgeul is always true
.*:2844: Warning: branch bgeul is always true
.*:2919: Warning: branch blel is always true
.*:2934: Warning: branch bleul is always true
.*:2940: Warning: branch bleul is always true
.*:2943: Warning: branch bleul is always true
.*:3010: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,0'
.*:3011: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,1<<2'
.*:3012: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,2<<2'
.*:3013: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,3<<2'
.*:3014: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,4<<2'
.*:3015: Error: opcode not supported in the `insn32' mode `addiur1sp \$2,63<<2'
.*:3016: Error: opcode not supported in the `insn32' mode `addiur1sp \$3,63<<2'
.*:3017: Error: opcode not supported in the `insn32' mode `addiur1sp \$4,63<<2'
.*:3018: Error: opcode not supported in the `insn32' mode `addiur1sp \$5,63<<2'
.*:3019: Error: opcode not supported in the `insn32' mode `addiur1sp \$6,63<<2'
.*:3020: Error: opcode not supported in the `insn32' mode `addiur1sp \$7,63<<2'
.*:3021: Error: opcode not supported in the `insn32' mode `addiur1sp \$16,63<<2'
.*:3022: Error: opcode not supported in the `insn32' mode `addiur1sp \$17,63<<2'
.*:3024: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$2,-1'
.*:3025: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$3,-1'
.*:3026: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$4,-1'
.*:3027: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$5,-1'
.*:3028: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$6,-1'
.*:3029: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$7,-1'
.*:3030: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$16,-1'
.*:3031: Error: opcode not supported in the `insn32' mode `addiur2 \$2,\$17,-1'
.*:3032: Error: opcode not supported in the `insn32' mode `addiur2 \$3,\$17,-1'
.*:3033: Error: opcode not supported in the `insn32' mode `addiur2 \$4,\$17,-1'
.*:3034: Error: opcode not supported in the `insn32' mode `addiur2 \$5,\$17,-1'
.*:3035: Error: opcode not supported in the `insn32' mode `addiur2 \$6,\$17,-1'
.*:3036: Error: opcode not supported in the `insn32' mode `addiur2 \$7,\$17,-1'
.*:3037: Error: opcode not supported in the `insn32' mode `addiur2 \$16,\$17,-1'
.*:3038: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,-1'
.*:3039: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,1'
.*:3040: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,4'
.*:3041: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,8'
.*:3042: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,12'
.*:3043: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,16'
.*:3044: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,20'
.*:3045: Error: opcode not supported in the `insn32' mode `addiur2 \$17,\$17,24'
.*:3047: Error: opcode not supported in the `insn32' mode `addiusp 2<<2'
.*:3048: Error: opcode not supported in the `insn32' mode `addiusp 3<<2'
.*:3049: Error: opcode not supported in the `insn32' mode `addiusp 254<<2'
.*:3050: Error: opcode not supported in the `insn32' mode `addiusp 255<<2'
.*:3051: Error: opcode not supported in the `insn32' mode `addiusp 256<<2'
.*:3052: Error: opcode not supported in the `insn32' mode `addiusp 257<<2'
.*:3053: Error: opcode not supported in the `insn32' mode `addiusp -3<<2'
.*:3054: Error: opcode not supported in the `insn32' mode `addiusp -4<<2'
.*:3055: Error: opcode not supported in the `insn32' mode `addiusp -255<<2'
.*:3056: Error: opcode not supported in the `insn32' mode `addiusp -256<<2'
.*:3057: Error: opcode not supported in the `insn32' mode `addiusp -257<<2'
.*:3058: Error: opcode not supported in the `insn32' mode `addiusp -258<<2'
.*:3060: Error: opcode not supported in the `insn32' mode `addius5 \$0,0'
.*:3061: Error: opcode not supported in the `insn32' mode `addius5 \$2,0'
.*:3062: Error: opcode not supported in the `insn32' mode `addius5 \$3,0'
.*:3063: Error: opcode not supported in the `insn32' mode `addius5 \$30,0'
.*:3064: Error: opcode not supported in the `insn32' mode `addius5 \$31,0'
.*:3065: Error: opcode not supported in the `insn32' mode `addius5 \$31,1'
.*:3066: Error: opcode not supported in the `insn32' mode `addius5 \$31,2'
.*:3067: Error: opcode not supported in the `insn32' mode `addius5 \$31,3'
.*:3068: Error: opcode not supported in the `insn32' mode `addius5 \$31,7'
.*:3069: Error: opcode not supported in the `insn32' mode `addius5 \$31,-6'
.*:3070: Error: opcode not supported in the `insn32' mode `addius5 \$31,-7'
.*:3071: Error: opcode not supported in the `insn32' mode `addius5 \$31,-8'
.*:4759: Warning: divide by zero
.*:4762: Warning: divide by zero
.*:4775: Warning: divide by zero
.*:5180: Warning: divide by zero
.*:5190: Warning: divide by zero
.*:5200: Warning: divide by zero
.*:5568: Error: opcode not supported in the `insn32' mode `jalr16 \$2'
.*:5572: Error: opcode not supported in the `insn32' mode `jr16 \$2'
.*:5579: Error: opcode not supported in the `insn32' mode `jals test_delay_slot'
.*:5580: Error: opcode not supported in the `insn32' mode `jalrs16 \$2'
.*:5581: Error: opcode not supported in the `insn32' mode `jalrs32 \$2'
.*:5582: Error: opcode not supported in the `insn32' mode `jrs \$2'
.*:5583: Error: opcode not supported in the `insn32' mode `jalrs\.hb \$2'
.*:5584: Error: opcode not supported in the `insn32' mode `jrs\.hb \$2'
.*:5665: Error: opcode not supported in the `insn32' mode `bals test_spec107'
.*:5667: Error: opcode not supported in the `insn32' mode `bgezals \$2,test_spec107'
.*:5669: Error: opcode not supported in the `insn32' mode `bltzals \$2,test_spec107'
