[^:]*: Assembler messages:
[^:]*:5: Error: indexed vector register expected at operand 1 -- `dup v0.b,v1.b\[7\]'
[^:]*:6: Error: operand 1 should be an integer register -- `mov r0.w,r1.w'
[^:]*:7: Error: operand 2 should be a SIMD vector element -- `dup s0,s1\[3\]'
