#readelf: -A
#name: C6X PIC attribute, directives 1
#as:
#source: attr-pic-directive-1.s

Attribute Section: c6xabi
File Attributes
  Tag_ISA: C674x
  Tag_ABI_PIC: Code addressing position-independent
