	.section .init,"ax",@progbits
	.p2align 2
	.space 0x1a
	.section .text,"ax",@progbits
	.p2align 4
	.space 0x3ab96
	.section .fini,"ax",@progbits
	.p2align 2
	.space 0x9
	.section .foo_hdr,"a",@progbits
	.p2align 2
	.space 0xd14
	.section .foo,"a",@progbits
	.p2align 3
	.space 0x4d5c
	.section .rodata,"a",@progbits
	.p2align 6
	.space 0xa54d
	.section .xxx,"a",@progbits
	.space 0xf43
	.section .yyy,"aw",@progbits
	.space 0x1
	.section .init_array,"aw",@init_array
	.p2align 3
	.space 0x10
	.section .fini_array,"aw",@fini_array
	.p2align 3
	.space 0x8
	.section	.tdata,"awT",%progbits
	.p2align 3
	.space 0x4
	.section	.tbss,"awT",%nobits
	.p2align 3
	.space 0x40
	.section	.data.rel.ro,"aw",%progbits
	.p2align 6
	.space 0x1b60
	.section .jcr,"aw",@progbits
	.p2align 3
	.space 0x8
	.section .bar,"aw",@progbits
	.p2align 3
	.space 0x640
	.section	.data,"aw",%progbits
	.p2align 5
	.space 0x70
	.section	.bss,"aw",%nobits
	.p2align 6
	.space 0x8a0
	.section	BUS_ERROR_MAP,"aw",%progbits
	.p2align 3
	.space 0x230
