
.lcomm column0,1,1
 .lcomm column1, 2,1
	.lcomm local3_noalign, 3

	.lcomm local4_aligned_2, 4, 2
	.lcomm another_align, 5, 4
	.lcomm nospaces,6,5
	.lcomm trailingspace,7,6	 	

	.lcomm align_max, 8, 15
