[^:]*: Assembler messages:
[^:]*:2: Error: Missing symbol name in directive
[^:]*:4: Error: Missing symbol name in directive
[^:]*:6: Error: Missing symbol name in directive
[^:]*:8: Error: Missing symbol name in directive
[^:]*:10: Error: Missing symbol name in directive
[^:]*:12: Error: Missing symbol name in directive
[^:]*:14: Error: Missing symbol name in directive
[^:]*:14: Error: expected comma after name in .symver
[^:]*:16: Error: Missing symbol name in directive
[^:]*:18: Error: Missing symbol name in directive
[^:]*:18: Error: unrecognized symbol type ""
