#readelf: -A
#name: C6X stack alignment attributes, directives 2
#as:
#source: attr-stack-directive-2.s

Attribute Section: c6xabi
File Attributes
  Tag_ISA: C674x
  Tag_ABI_stack_align_needed: 16-byte
  Tag_ABI_stack_align_preserved: 16-byte
