#source: pr20244-2.s
#as: --32
#ld: -m elf_i386
#readelf: -rW
#notarget: i?86-*-nacl* x86_64-*-nacl*

Relocation section '.rel.plt' at offset 0x74 contains 2 entries:
 Offset     Info    Type                Sym. Value  Symbol's Name
0+80490e4  0000002a R_386_IRELATIVE       
0+80490e0  0000002a R_386_IRELATIVE       
