	.file	"sec-to-seg2.s"

	.section	.rodata
	.align	2
	.ascii	"zzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzz\000"
	.align	2
	.ascii	"55555555555555555555555555555555\000"
	.align	2
	.ascii	"xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx\000"
	.align	2
	.ascii	"99999999999999999999999999999999\000"


