! translate opcodes

	.text
	.z8001

	trdb	@rr2,@rr4,r6
	trdrb	@rr2,@rr4,r6
	trib	@rr12,@rr10,r7
	trirb	@rr12,@rr10,r8
	trtdb	@rr6,@rr8,r10
	trtdrb	@rr8,@rr4,r3
	trtib	@rr10,@rr2,r12
	trtirb	@rr2,@rr4,r6

	.end
