.*: Assembler messages:
.*:1: Error: Instruction not supported by this architecture
.*:2: Error: Instruction not supported by this architecture
.*:3: Error: Instruction not supported by this architecture
.*:4: Error: Instruction not supported by this architecture
.*:5: Error: Instruction not supported by this architecture
.*:6: Error: Instruction not supported by this architecture
.*:7: Error: Instruction not supported by this architecture
