	.data
	.type	bar, @object
bar:
	.byte	1
	.size	bar, .-bar
	.globl	foo
	.type	foo, @object
foo:
	.byte	1
	.size	foo, .-foo
	.text
	.globl	_start
	.type	_start, @function
_start:
	movl	$0, bar@GOT
	cmpl	$0, foo@GOT
	movl	$bar@GOT, %ecx
