	.text
	vcvtt.f32.f16		s0, s1
	vcvtteq.f32.f16		s2, s3
	vcvttne.f32.f16		s2, s3
	vcvttcs.f32.f16		s2, s3
	vcvttcc.f32.f16		s2, s3
	vcvttmi.f32.f16		s2, s3
	vcvttpl.f32.f16		s2, s3
	vcvttvs.f32.f16		s2, s3
	vcvttvc.f32.f16		s2, s3
	vcvtthi.f32.f16		s2, s3
	vcvttls.f32.f16		s2, s3
	vcvttge.f32.f16		s2, s3
	vcvttlt.f32.f16		s2, s3
	vcvttgt.f32.f16		s2, s3
	vcvttle.f32.f16		s2, s3
	vcvttal.f32.f16		s2, s3

	vcvtt.f16.f32		s0, s1
	vcvtteq.f16.f32		s2, s3
	vcvttne.f16.f32		s2, s3
	vcvttcs.f16.f32		s2, s3
	vcvttcc.f16.f32		s2, s3
	vcvttmi.f16.f32		s2, s3
	vcvttpl.f16.f32		s2, s3
	vcvttvs.f16.f32		s2, s3
	vcvttvc.f16.f32		s2, s3
	vcvtthi.f16.f32		s2, s3
	vcvttls.f16.f32		s2, s3
	vcvttge.f16.f32		s2, s3
	vcvttlt.f16.f32		s2, s3
	vcvttgt.f16.f32		s2, s3
	vcvttle.f16.f32		s2, s3
	vcvttal.f16.f32		s2, s3

	vcvtb.f32.f16		s0, s1
	vcvtbeq.f32.f16		s2, s3
	vcvtbne.f32.f16		s2, s3
	vcvtbcs.f32.f16		s2, s3
	vcvtbcc.f32.f16		s2, s3
	vcvtbmi.f32.f16		s2, s3
	vcvtbpl.f32.f16		s2, s3
	vcvtbvs.f32.f16		s2, s3
	vcvtbvc.f32.f16		s2, s3
	vcvtbhi.f32.f16		s2, s3
	vcvtbls.f32.f16		s2, s3
	vcvtbge.f32.f16		s2, s3
	vcvtblt.f32.f16		s2, s3
	vcvtbgt.f32.f16		s2, s3
	vcvtble.f32.f16		s2, s3
	vcvtbal.f32.f16		s2, s3

	vcvtb.f16.f32		s0, s1
	vcvtbeq.f16.f32		s2, s3
	vcvtbne.f16.f32		s2, s3
	vcvtbcs.f16.f32		s2, s3
	vcvtbcc.f16.f32		s2, s3
	vcvtbmi.f16.f32		s2, s3
	vcvtbpl.f16.f32		s2, s3
	vcvtbvs.f16.f32		s2, s3
	vcvtbvc.f16.f32		s2, s3
	vcvtbhi.f16.f32		s2, s3
	vcvtbls.f16.f32		s2, s3
	vcvtbge.f16.f32		s2, s3
	vcvtblt.f16.f32		s2, s3
	vcvtbgt.f16.f32		s2, s3
	vcvtble.f16.f32		s2, s3
	vcvtbal.f16.f32		s2, s3
