#source: attr-merge-wchar-4.s
#source: attr-merge-wchar-2.s
#as:
#ld: -r
#warning: warning: .* uses 2-byte wchar_t yet the output is to use 4-byte wchar_t; use of wchar_t values across objects may fail
