
Elf file type is EXEC.*
Entry point 0x0
There are 2 program headers, starting at offset [0-9]+

Program Headers:
  Type           Offset   VirtAddr   PhysAddr   FileSiz MemSiz  Flg Align
  LOAD ( +0x[0-9a-f]+){5} R E 0x[0-9a-f]+
  LOAD ( +0x[0-9a-f]+){5} ([RWE ]+){3} 0x[0-f]+

 Section to Segment mapping:
  Segment Sections...
   00     .text_vle .text_iv .iv_handlers 
   01     .data 
