#as: -EL
#objdump: -s
#name: MicroBlaze Little Endian
#source: endian.s

.*:     file format elf32-microblazeel

Contents of section .text:
 0000 d2042020 78563412 34120000 00000000  ..  xV4.4.......
