; Test C64x+ M-unit compact instruction formats
	.text
	nop
	.align 16
	nop
	.align 16
m3_op_00:
	.short 0x231e
	.short 0x469f
	.short 0x799e
	.short 0x9c1f
	.short 0xa71e
	.short 0xca9f
	.short 0xfd9e
m3_op_01:
	.short 0x213e
	.short 0x46bf
	.short 0x7bbe
	.short 0x9c3f
	.short 0xa53e
	.short 0xcabf
	.short 0xffbe
	.word  0xefe00000
m3_op_10:
	.short 0x225e
	.short 0x47df
	.short 0x78de
	.short 0x9d5f
	.short 0xa6de
	.short 0xcbdf
	.short 0xfc5e
m3_op_11:
	.short 0x207e
	.short 0x45ff
	.short 0x7afe
	.short 0x9f7f
	.short 0xa47e
	.short 0xc9ff
	.short 0xfefe
	.word  0xefe80000
m3_op_00_sat:
	.short 0x231e
	.short 0x469f
	.short 0x799e
	.short 0x9c1f
	.short 0xa71e
	.short 0xca9f
	.short 0xfd9e
m3_op_01_sat:
	.short 0x213e
	.short 0x46bf
	.short 0x7bbe
	.short 0x9c3f
	.short 0xa53e
	.short 0xcabf
	.short 0xffbe
	.word  0xefe84000
m3_op_10_sat:
	.short 0x225e
	.short 0x47df
	.short 0x78de
	.short 0x9d5f
	.short 0xa6de
	.short 0xcbdf
	.short 0xfc5e
m3_op_11_sat:
	.short 0x207e
	.short 0x45ff
	.short 0x7afe
	.short 0x9f7f
	.short 0xa47e
	.short 0xc9ff
	.short 0xfefe
	.word  0xefe04000
