[^:]*: Assembler messages:
[^:]*:4: Error: unexpected \.handlerdata directive
[^:]*:9: Error: duplicate \.personalityindex directive
[^:]*:11: Error: personality routine specified for cantunwind frame
[^:]*:19: Error: personality routine specified for cantunwind frame
[^:]*:29: Error: duplicate \.personality directive
[^:]*:32: Error: unexpected \.cantunwind directive
[^:]*:34: Error: duplicate \.handlerdata directive
[^:]*:41: Error: personality routine required before \.handlerdata directive
[^:]*:48: Error: bad personality routine number
[^:]*:50: Error: bad personality routine number
[^:]*:59: Error: missing \.endp before \.cfi_startproc
