ARCH=avr:100
MACHINE=
SCRIPT_NAME=avrtiny
OUTPUT_FORMAT="elf32-avr"
MAXPAGESIZE=1
EMBEDDED=yes
TEMPLATE_NAME=elf32

TEXT_ORIGIN=0x0
TEXT_LENGTH=4K
DATA_ORIGIN=0x0800040
DATA_LENGTH=0x100
EXTRA_EM_FILE=avrelf
