#objdump: -dr

dump\.o:     file format .*


Disassembly of section \.text:

00000000 <\.text>:
   0:	fd 04 00                      	machi	r0, r0
   3:	fd 04 0f                      	machi	r0, r15
   6:	fd 04 f0                      	machi	r15, r0
   9:	fd 04 ff                      	machi	r15, r15
