[^:]*: Assembler messages:
[^:]*:5: Error: instruction 'nop' cannot be predicated
[^:]*:6: Error: instruction 'nop' cannot be predicated
[^:]*:7: Error: instruction 'addab' cannot be predicated
[^:]*:8: Error: instruction 'addah' cannot be predicated
[^:]*:9: Error: instruction 'addaw' cannot be predicated
[^:]*:10: Error: instruction 'callp' cannot be predicated
[^:]*:11: Error: instruction 'addsub' cannot be predicated
[^:]*:12: Error: instruction 'addsub2' cannot be predicated
[^:]*:13: Error: instruction 'cmpy' cannot be predicated
[^:]*:14: Error: instruction 'cmpyr' cannot be predicated
[^:]*:15: Error: instruction 'cmpyr1' cannot be predicated
[^:]*:16: Error: instruction 'ddotp4' cannot be predicated
[^:]*:17: Error: instruction 'ddotph2' cannot be predicated
[^:]*:18: Error: instruction 'ddotph2r' cannot be predicated
[^:]*:19: Error: instruction 'ddotpl2' cannot be predicated
[^:]*:20: Error: instruction 'ddotpl2r' cannot be predicated
[^:]*:21: Error: instruction 'dint' cannot be predicated
[^:]*:22: Error: instruction 'dpack2' cannot be predicated
[^:]*:23: Error: instruction 'dpackx2' cannot be predicated
[^:]*:24: Error: instruction 'gmpy' cannot be predicated
[^:]*:25: Error: instruction 'idle' cannot be predicated
[^:]*:26: Error: instruction 'mpy2ir' cannot be predicated
[^:]*:27: Error: instruction 'rint' cannot be predicated
[^:]*:28: Error: instruction 'rpack2' cannot be predicated
[^:]*:29: Error: instruction 'saddsub' cannot be predicated
[^:]*:30: Error: instruction 'saddsub2' cannot be predicated
[^:]*:31: Error: instruction 'shfl3' cannot be predicated
[^:]*:32: Error: instruction 'smpy32' cannot be predicated
[^:]*:33: Error: instruction 'swe' cannot be predicated
[^:]*:34: Error: instruction 'swenr' cannot be predicated
[^:]*:35: Error: instruction 'xormpy' cannot be predicated
[^:]*:36: Error: instruction 'spmask' cannot be predicated
[^:]*:37: Error: instruction 'spmaskr' cannot be predicated
[^:]*:39: Error: instruction 'spkernel' cannot be predicated
[^:]*:40: Error: instruction 'spkernelr' cannot be predicated
