; Test C64x+ L-unit compact instruction formats
	.text
	nop
	.align 16
	nop
	.align 16
l3_nosat_l:
	.short 0x0010
	.short 0x2120
	.short 0x4230
	.short 0x6340
	.short 0x8050
	.short 0xa160
	.short 0xc270
	.short 0xeb80
	.short 0x0890
	.short 0x29a0
	.short 0x4ab0
	.short 0x6bc0
	.short 0x88d0
	.short 0xa9e0
	.word  0xefe00000
l3_sat_h:
	.short 0xc2f0
	.short 0xe300
	.short 0x0010
	.short 0x2120
	.short 0x4230
	.short 0x6340
	.short 0x8050
	.short 0xa960
	.short 0xca70
	.short 0xeb80
	.short 0x0890
	.short 0x29a0
	.short 0x4ab0
	.short 0x6bc0
	.word  0xefe84000
l3i:
	.short 0x0410
	.short 0x3520
	.short 0x4630
	.short 0x7740
	.short 0x8550
	.short 0xb660
	.short 0xc770
	.short 0x1c80
	.short 0x2d90
	.short 0x5ea0
	.short 0x6fb0
	.short 0x9cc0
	.short 0xadd0
	.short 0xdee0
	.word  0xefe00000
l2c_op_000:
	.short 0x0408
	.short 0x2409
	.short 0x4418
	.short 0x6419
	.short 0x9408
	.short 0xb409
	.short 0xd418
l2c_op_001:
	.short 0xf439
	.short 0x2428
	.short 0x4429
	.short 0x6438
	.short 0x8439
	.short 0xb428
	.short 0xd429
	.word  0xefe00000
l2c_op_010:
	.short 0x0458
	.short 0x2449
	.short 0x4448
	.short 0x6459
	.short 0x9458
	.short 0xb449
	.short 0xd448
l2c_op_011:
	.short 0xf479
	.short 0x2468
	.short 0x4469
	.short 0x6478
	.short 0x8479
	.short 0xb468
	.short 0xd469
	.word  0xefe80000
l2c_op_100:
	.short 0x0c18
	.short 0x2c09
	.short 0x4c08
	.short 0x6c19
	.short 0x9c18
	.short 0xbc09
	.short 0xdc08
l2c_op_101:
	.short 0xfc39
	.short 0x2c28
	.short 0x4c29
	.short 0x6c38
	.short 0x8c39
	.short 0xbc28
	.short 0xdc29
	.word  0xefe00000
l2c_op_110:
	.short 0x0c58
	.short 0x2c49
	.short 0x4c48
	.short 0x6c59
	.short 0x9c58
	.short 0xbc49
	.short 0xdc48
l2c_op_111:
	.short 0xfc79
	.short 0x2c68
	.short 0x4c69
	.short 0x6c78
	.short 0x8c79
	.short 0xbc68
	.short 0xdc69
	.word  0xefe80000
lx5:
	.short 0x0426
	.short 0x2527
	.short 0x46a6
	.short 0x67a7
	.short 0x8626
	.short 0xa527
	.short 0xc4a6
	.short 0xf5a7
	.short 0x1626
	.short 0x3727
	.short 0x56a6
	.short 0x75a7
	.short 0x9426
	.short 0xb527
	.word  0xefe00000
lx3c:
	.short 0x0026
	.short 0x2127
	.short 0x42a6
	.short 0x63a7
	.short 0x8226
	.short 0xa127
	.short 0xc0a6
	.short 0xe1a7
	.short 0x0226
	.short 0x2327
	.short 0x42a6
	.short 0x61a7
	.short 0x8026
	.short 0xa127
	.word  0xefe00000
lx1c:
	.short 0x1026
	.short 0x3127
	.short 0x52a6
	.short 0x73a7
	.short 0x9226
	.short 0xb127
	.short 0xd0a6
	.short 0xf1a7
	.short 0x1226
	.short 0x3327
	.short 0x52a6
	.short 0x71a7
	.short 0x9026
	.short 0xb127
	.word  0xefe00000
lx1:
	.short 0x5b66
	.short 0x5a67
	.short 0x59e6
	.short 0x58e7
	.short 0x5866
	.short 0x5967
	.short 0x5ae6
	.short 0x7be7
	.short 0x7b66
	.short 0x7a67
	.short 0x79e6
	.short 0x78e7
	.short 0x7866
	.short 0x7967
	.word  0xefe00000
