# lp test

	lp	text_label
	lpal	text_label
	lpra	text_label
	lpeq	text_label
	lpz	text_label
	lpne	text_label
	lpnz	text_label
	lppl	text_label
	lpp	text_label
	lpmi	text_label
	lpn	text_label
	lpcs	text_label
	lpc	text_label
	lplo	text_label
	lpcc	text_label
	lpnc	text_label
	lphs	text_label
	lpvs	text_label
	lpv	text_label
	lpvc	text_label
	lpnv	text_label
	lpgt	text_label
	lpge	text_label
	lplt	text_label
	lple	text_label
	lphi	text_label
	lpls	text_label
	lppnz	text_label

	nop_s
text_label:
