[^:]*: Assembler messages:
[^:]*:26: s suffix on comparison instruction is deprecated
[^:]*:29: s suffix on comparison instruction is deprecated
[^:]*:32: s suffix on comparison instruction is deprecated
[^:]*:35: s suffix on comparison instruction is deprecated
