	.text
start:
	vmul10cuq    11,30
	vcmpneb      30,1,23
	vpermr       30,19,30,29
	vmul10ecuq   20,20,17
	vcmpneh      27,19,31
	vrlwmi       6,9,23
	vcmpnew      22,26,1
	vrldmi       24,30,25
	vcmpnezb     19,29,22
	vcmpnezh     8,23,19
	vrlwnm       27,24,11
	vcmpnezw     21,13,10
	vrldnm       5,20,29
	vmul10uq     30,19
	vextractub   24,21,12
	vmul10euq    0,19,28
	vextractuh   10,3,12
	vextractuw   28,12,7
	vextractd    30,27,1
	vinsertb     25,31,4
	bcdcpsgn.    21,14,30
	vinserth     22,18,5
	vinsertw     29,22,1
	vinsertd     29,13,7
	vcmpneb.     22,25,8
	vcmpneh.     16,15,21
	bcdus.       22,21,31
	vcmpnew.     1,12,12
	bcds.        5,3,8,1
	bcdtrunc.    27,22,1,0
	vcmpnezb.    2,26,0
	bcdutrunc.   26,14,7
	vcmpnezh.    16,5,12
	bcdctsq.     24,5
	bcdcfsq.     7,0,0
	bcdctz.      30,12,1
	bcdctn.      17,23
	bcdcfz.      4,15,1
	bcdcfn.      29,5,1
	bcdsetsgn.   27,12,0
	vcmpnezw.    14,28,25
	bcdsr.       2,2,6,1
	vbpermd      25,0,5
	vclzlsbb     28,25
	vctzlsbb     2,24
	vnegw        21,11
	vnegd        17,27
	vprtybw      31,23
	vprtybd      21,23
	vprtybq      21,18
	vextsb2w     30,4
	vextsh2w     3,26
	vextsb2d     11,17
	vextsh2d     5,10
	vextsw2d     13,25
	vctzb        25,2
	vctzh        0,3
	vctzw        22,6
	vctzd        26,24
	vextublx     6,31,2
	vextuhlx     13,0,18
	vextuwlx     14,30,31
	vsrv         15,12,14
	vextubrx     20,10,30
	vslv         21,21,2
	vextuhrx     15,9,1
	vextuwrx     21,17,16
	vmsumudm     20,21,22,23
