       .arch   armv6

foo:
       srsdb   r13, #13
       srsdb   r13!, #13
       srsia   r13, #13
       srsia   r13!, #13
       srsda   r13, #13
       srsda   r13!, #13
       srsib   r13, #13
       srsib   r13!, #13
       srsdb   r4, #13
       srsda   r4, #13
       srsia   r4, #13
       srsib   r4, #13
       srsea   r13, #13
       srsea   r13!, #13
       srsfd   r13, #13
       srsfd   r13!, #13
       srsfa   r13, #13
       srsfa   r13!, #13
       srsed   r13, #13
       srsed   r13!, #13
       srsea   r4, #13
       srsfd   r4, #13
       srsfa   r4, #13
       srsed   r4, #13
       srs     r13, #13
       srs     r13!, #13
       srs     r4, #13
