.*: Assembler messages:
.*:17: Warning: wrong size instruction in a 16-bit branch delay slot
.*:19: Warning: wrong size instruction in a 16-bit branch delay slot
.*:21: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:40: Warning: wrong size instruction in a 16-bit branch delay slot
.*:44: Warning: wrong size instruction in a 16-bit branch delay slot
.*:46: Warning: wrong size instruction in a 16-bit branch delay slot
.*:71: Warning: wrong size instruction in a 16-bit branch delay slot
.*:90: Warning: macro instruction expanded into multiple instructions in a branch delay slot
.*:92: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:94: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:96: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:98: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:100: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:100: Warning: macro instruction expanded into multiple instructions in a branch delay slot
.*:110: Warning: macro instruction expanded into multiple instructions in a branch delay slot
.*:121: Warning: macro instruction expanded into multiple instructions in a branch delay slot
.*:123: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:125: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:127: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:129: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:131: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:131: Warning: macro instruction expanded into multiple instructions in a branch delay slot
.*:141: Warning: macro instruction expanded into multiple instructions in a branch delay slot
