#name: NIOS2 R_NIOS2_BFD_RELOC_XX
#source: reloc.s
#source: reloc_symbol.s
#ld:
#objdump: -s

.*: +file format elf32-littlenios2

Contents of section .text:
 [0-9a-f]+ fa00cefa efbeadde facefaef beadde00  ................
